---
title: "Test chunk options in Rmd/Jupyter conversion"
author: "Marc Wouts"
date: "June 16, 2018"
jupyter:
  kernelspec:
    display_name: Python
    language: python
    name: python3
---

```{r knitr_setup, include=FALSE}
knitr::opts_chunk$set(echo = FALSE, fig.width = 10, fig.height = 5)
```


```{python echo=TRUE}
import pandas as pd
x = pd.Series({'A':1, 'B':3, 'C':2})
```

```{python bar_plot, echo=FALSE, fig.height=5, fig.width=8}
x.plot(kind='bar', title='Sample plot')
```

